@@ -1,5 +1,13 @@
+import _BrowserRouter from './BrowserRouter';
+export { _BrowserRouter as BrowserRouter };
+import _HashRouter from './HashRouter';
+export { _HashRouter as HashRouter };
+import _Link from './Link';
+export { _Link as Link };
 import _MemoryRouter from './MemoryRouter';
 export { _MemoryRouter as MemoryRouter };
+import _NavLink from './NavLink';
+export { _NavLink as NavLink };
 import _Prompt from './Prompt';
 export { _Prompt as Prompt };
 import _Redirect from './Redirect';
